@@ -1,12 +1,12 @@
 from unittest2 import TestCase
+from pillowtop import get_all_pillows
 from pillowtop.listener import BasicPillow
-from pillowtop.utils import import_pillows
 from inspect import isclass
 
 
 def import_settings():
     class MockSettings(object):
-        PILLOWTOPS = ['pillowtop.tests.FakePillow']
+        PILLOWTOPS = {'test': ['pillowtop.tests.FakePillow']}
 
     return MockSettings()
 
@@ -18,15 +18,15 @@ class PillowTopTestCase(TestCase):
         pillowtop.utils.import_settings = import_settings
 
     def test_import_pillows_class_only(self):
-        pillows = import_pillows(instantiate=False)
+        pillows = get_all_pillows(instantiate=False)
         self.assertEquals(len(pillows), 1)
         self.assertTrue(isclass(pillows[0]))
 
     def test_import_pillows(self):
-        pillows = import_pillows(instantiate=True)
+        pillows = get_all_pillows(instantiate=True)
         self.assertEquals(len(pillows), 1)
         self.assertFalse(isclass(pillows[0]))
 
 
 class FakePillow(BasicPillow):
-    pass
\ No newline at end of file
+    pass
